@@ -16,10 +16,18 @@ function(dose,parm){
 
     dose<-matrix(dose,ncol=1)
 
-    if(ftype==4)return(apply(X=dose,MARGIN=1,FUN=e4,led50 = parm[,1], 
-        lambda = parm[,2], emax = parm[,3], e0 = parm[,4]))
-    if(ftype==3)return(apply(X=dose,MARGIN=1,FUN=e3,led50 = parm[,1], 
-        emax = parm[,2], e0 = parm[,3]))
+    if(ftype==4){
+        tout<-apply(X=dose,MARGIN=1,FUN=e4,led50 = parm[,1], 
+            lambda = parm[,2], emax = parm[,3], e0 = parm[,4])
+        if(length(dose)==1) tout<-as.vector(tout)
+        return(tout)
+    }
+    if(ftype==3){
+        tout<-apply(X=dose,MARGIN=1,FUN=e3,led50 = parm[,1], 
+              emax = parm[,2], e0 = parm[,3])
+        if(length(dose)==1) tout<-as.vector(tout)
+        return(tout)           
+    }
 }
 
 e4<-function(dose,led50,lambda,emax,e0){
